
# Type: latitude


latitude

URI: [biolink:latitude](https://w3id.org/biolink/vocab/latitude)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Float](types/Float.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [GeographicLocation](GeographicLocation.md)
 * [GeographicLocationAtTime](GeographicLocationAtTime.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | wgs:lat |

